@@ -1,6 +1,3 @@
-# -*- coding: utf-8 -*-
-import os
-
 DATABASES = {
     'default': {
         'ENGINE': 'django.db.backends.sqlite3',
@@ -10,19 +7,19 @@ DATABASES = {
 
 INSTALLED_APPS = [
     'localflavor',
+    'tests.test_br',
     'tests.test_au',
     'tests.test_ec',
+    'tests.test_md',
     'tests.test_mk',
     'tests.test_mx',
+    'tests.test_ua',
     'tests.test_us',
     'tests.test_pk',
+    'tests.test_cu',
+    'tests.test_generic',
 ]
 
-import django
-
-if django.VERSION[:2] < (1, 6):
-    TEST_RUNNER = 'discover_runner.DiscoverRunner'
-
 SECRET_KEY = 'spam-spam-spam-spam'
 
 SILENCED_SYSTEM_CHECKS = ('1_7.W001',)
